==> open-xchange-appsuite-backend_7.2.2.orig.tar.bz2: open-xchange-appsuite-backend-7.2.2/com.openexchange.printing/src/com/openexchange/printing/osgi/PrintingActivator.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.printing.osgi;

import com.openexchange.ajax.requesthandler.osgiservice.AJAXModuleActivator;
import com.openexchange.i18n.I18nService;
import com.openexchange.printing.contacts.ContactTemplateHelperFactory;
import com.openexchange.printing.email.EmailTemplateHelperFactory;
import com.openexchange.printing.tasks.TaskTemplateHelperFactory;
import com.openexchange.templating.TemplateHelperFactory;
import com.openexchange.user.UserService;

public class PrintingActivator extends AJAXModuleActivator {

	@Override
	protected Class<?>[] getNeededServices() {
		return new Class[]{ I18nService.class, UserService.class};
	}

	@Override
	protected void startBundle() throws Exception {
		PrintingServices.LOOKUP.set(this);

        registerService(TemplateHelperFactory.class, new ContactTemplateHelperFactory(this));
        registerService(TemplateHelperFactory.class, new TaskTemplateHelperFactory(this));
        registerService(TemplateHelperFactory.class, new EmailTemplateHelperFactory(this));
	}
	
	protected void stopBundle() throws Exception {
		PrintingServices.LOOKUP.set(null);
		super.stopBundle();
	}
}

==> open-xchange-appsuite-backend_7.4.0.orig.tar.bz2: open-xchange-appsuite-backend-7.4.0/com.openexchange.printing/src/com/openexchange/printing/osgi/PrintingActivator.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.printing.osgi;

import com.openexchange.ajax.requesthandler.osgiservice.AJAXModuleActivator;
import com.openexchange.i18n.I18nService;
import com.openexchange.printing.contacts.ContactTemplateHelperFactory;
import com.openexchange.printing.email.EmailTemplateHelperFactory;
import com.openexchange.printing.tasks.TaskTemplateHelperFactory;
import com.openexchange.templating.TemplateHelperFactory;
import com.openexchange.user.UserService;

/**
 * {@link PrintingActivator} - The activator for printing module.
 *
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 */
public class PrintingActivator extends AJAXModuleActivator {

    @Override
    protected Class<?>[] getNeededServices() {
        return new Class[] { UserService.class };
    }

    @Override
    protected void startBundle() throws Exception {
        PrintingServices.LOOKUP.set(this);

        trackService(I18nService.class);

        registerService(TemplateHelperFactory.class, new ContactTemplateHelperFactory(this));
        registerService(TemplateHelperFactory.class, new TaskTemplateHelperFactory(this));
        registerService(TemplateHelperFactory.class, new EmailTemplateHelperFactory(this));
    }

    @Override
    protected void stopBundle() throws Exception {
        PrintingServices.LOOKUP.set(null);
        super.stopBundle();
    }
}
